==> xmbdfed-2.2.tar.gz: xmbdfed-2.2/GEShared.h <==
/*
 * Copyright 1996, 1997 Computing Research Labs, New Mexico State University
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE COMPUTING RESEARCH LAB OR NEW MEXICO STATE UNIVERSITY BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
 * OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
 * THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef _h_XmuttGEditShared
#define _h_XmuttGEditShared

/*
 * $Id: GEShared.h,v 1.2 1997/01/06 18:25:13 mleisher Exp $
 */

/*
 * Various things share by the glyph editor and the toolbar.
 */
#define _XmuttGLYPHEDIT_SELECT        0

#define XmuttGLYPHEDIT_DRAW           1
#define XmuttGLYPHEDIT_MOVE           2
#define XmuttGLYPHEDIT_COPY           3
#define XmuttGLYPHEDIT_FLIP_HORIZ     4
#define XmuttGLYPHEDIT_FLIP_VERT      5
#define XmuttGLYPHEDIT_ROT_LEFT       6
#define XmuttGLYPHEDIT_ROT_RIGHT      7
#define XmuttGLYPHEDIT_SHIFT_ULEFT    8
#define XmuttGLYPHEDIT_SHIFT_UP       9
#define XmuttGLYPHEDIT_SHIFT_URIGHT   10
#define XmuttGLYPHEDIT_SHIFT_LEFT     11
#define XmuttGLYPHEDIT_CROP           12
#define XmuttGLYPHEDIT_SHIFT_RIGHT    13
#define XmuttGLYPHEDIT_SHIFT_DLEFT    14
#define XmuttGLYPHEDIT_SHIFT_DOWN     15
#define XmuttGLYPHEDIT_SHIFT_DRIGHT   16

#endif /* _h_XmuttGEditShared */

==> xmbdfed-2.4.tar.gz: xmbdfed-2.4/GEShared.h <==
/*
 * Copyright 1996, 1997 Computing Research Labs, New Mexico State University
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE COMPUTING RESEARCH LAB OR NEW MEXICO STATE UNIVERSITY BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
 * OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
 * THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef _h_XmuttGEditShared
#define _h_XmuttGEditShared

/*
 * $Id: GEShared.h,v 1.3 1997/10/08 05:24:25 mleisher Exp $
 */

/*
 * Various things share by the glyph editor and the toolbar.
 */
#define _XmuttGLYPHEDIT_SELECT        0

#define XmuttGLYPHEDIT_DRAW           1
#define XmuttGLYPHEDIT_MOVE           2
#define XmuttGLYPHEDIT_COPY           3
#define XmuttGLYPHEDIT_FLIP_HORIZ     4
#define XmuttGLYPHEDIT_FLIP_VERT      5
#define XmuttGLYPHEDIT_SHEAR          6
#define XmuttGLYPHEDIT_ROT_LEFT       7
#define XmuttGLYPHEDIT_ROT_RIGHT      8
#define XmuttGLYPHEDIT_ROTATE         9
#define XmuttGLYPHEDIT_SHIFT_ULEFT    10
#define XmuttGLYPHEDIT_SHIFT_UP       11
#define XmuttGLYPHEDIT_SHIFT_URIGHT   12
#define XmuttGLYPHEDIT_SHIFT_LEFT     13
#define XmuttGLYPHEDIT_CROP           14
#define XmuttGLYPHEDIT_SHIFT_RIGHT    15
#define XmuttGLYPHEDIT_SHIFT_DLEFT    16
#define XmuttGLYPHEDIT_SHIFT_DOWN     17
#define XmuttGLYPHEDIT_SHIFT_DRIGHT   18

#endif /* _h_XmuttGEditShared */
